about summary refs log tree commit diff
path: root/stdlib/strtod.c
diff options
context:
space:
mode:
Diffstat (limited to 'stdlib/strtod.c')
-rw-r--r--stdlib/strtod.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/stdlib/strtod.c b/stdlib/strtod.c
index 8ce6e4d016..4104a98f0e 100644
--- a/stdlib/strtod.c
+++ b/stdlib/strtod.c
@@ -911,9 +911,9 @@ INTERNAL (STRTOF) (nptr, endptr, group)
 	    {
 	      if (num[0] >= d1)
 		{
 		  /* The nominator of the number occupies fewer bits than
 		     the denominator but the one limb is bigger than the
-		     high limb of the nominator.  */
+		     high limb of the numerator.  */
 		  n1 = 0;
 		  n0 = num[0];
 		}
@@ -911,9 +911,9 @@ INTERNAL (STRTOF) (nptr, endptr, group)
 	      if (num[0] >= d1)
 		{
-		  /* The nominator of the number occupies fewer bits than
+		  /* The numerator of the number occupies fewer bits than
 		     the denominator but the one limb is bigger than the